from setuptools import setup

setup(
    name='fmyar binom quantile',
    version='0.1.0',
    description='A example Python package',
    url='https://example.com/',
    author='Yaroslav Ilin',
    author_email='fmyar@vk.com',
    license='BSD 2-clause',
    packages=['superPackage'],
    install_requires=[
        'scipy',
    ],
)
